@@ -68,7 +68,7 @@ if [ -z "$target_part" ]; then
 fi
 
 # Make sure target_part is partition device name, not disk device name
-if [ -z "$(echo $target_part | grep -iE "/dev/[hs]d[a-z]+[[:digit:]]+")" ]; then
+if [ -z "$(echo $target_part | grep -iE "/dev/[hsu][bd][a-z]+[[:digit:]]+")" ]; then
   [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
   echo "\"$target_part\" is NOT a valid partition name!"
   [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
@@ -173,6 +173,10 @@ echo "We need a filesystem supporting Unix file mode for syslinux. Copying sysli
 syslinux_tmpd="$(mktemp -d /tmp/syslinux.XXXXXX)"
 cp -fv syslinux $syslinux_tmpd
 chmod u+x $syslinux_tmpd/syslinux
-echo "Running: $syslinux_tmpd/syslinux -fs $target_part"
-$syslinux_tmpd/syslinux -fs $target_part
+echo "Running: $syslinux_tmpd/syslinux -f $target_part "
+$syslinux_tmpd/syslinux -f $target_part
+echo "done!"
+[ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
+echo "//NOTE// If your USB flash drive fails to boot (maybe buggy BIOS), try to use \"syslinux -fs $target_part\", i.e. running with \"-s\"."
+[ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
 [ -d "$syslinux_tmpd" -a -n "$syslinux_tmpd" ] && rm -rf $syslinux_tmpd
